==> topcoder-react-utils-0.4.3.tgz: package/src/client/index.jsx <==
/**
 * Initialization of client-side code.
 */

/* global document window */

import React from 'react';
import ReactDom from 'react-dom';
import shortId from 'shortid';
import { Provider } from 'react-redux';
import { BrowserRouter } from 'react-router-dom';

/**
 * Renders given application into DOM, providing it with Redux store, if given.
 * @param {Function} Application Root ReactJS component of the app.
 * @param {Object} store Optional. Redux store.
 */
function render(Application, store) {
  let app = <BrowserRouter><Application /></BrowserRouter>;
  if (store) app = <Provider store={store}>{app}</Provider>;
  ReactDom.hydrate(app, document.getElementById('react-view'));
}

/**
 * Initializes the code at client side. It takes care about receiving the data
 * injected at the server-side, and also about setting up client side of hot
 * module reloading (HMR).
 * @param {String} applicationModulePath Optional.
 * @param {Function} getApplication
 * @param {Object} moduleHot
 * @param {Function} storeFactory Optional.
 */
export default async function Launch({
  applicationModulePath,
  getApplication,
  moduleHot,
  storeFactory,
}) {
  let store;
  if (storeFactory) {
    store = await storeFactory(window.ISTATE);
  }
  render(getApplication(), store);

  if (moduleHot && applicationModulePath) {
    moduleHot.accept(applicationModulePath, () =>
      render(getApplication(), store));

    /* HMR of CSS code each time webpack hot middleware updates the code. */
    /* eslint-disable no-underscore-dangle */
    const hotReporter = window.__webpack_hot_middleware_reporter__;
    /* eslint-enable no-underscore-dangle */
    const hotSuccess = hotReporter.success;
    hotReporter.success = () => {
      const stamp = shortId();
      const links = document.querySelectorAll('link[rel=stylesheet]');
      for (let i = 0; i < links.length; i += 1) {
        links[i].href = `${links[i].href.match(/[^?]*/)}?v=${stamp}`;
      }
      hotSuccess();
    };
  }
}

==> topcoder-react-utils-0.5.2.tgz: package/src/client/index.jsx <==
/**
 * Initialization of client-side code.
 */

/* global document window */

import React from 'react';
import ReactDom from 'react-dom';
import shortId from 'shortid';
import { Provider } from 'react-redux';
import { BrowserRouter } from 'react-router-dom';

/**
 * Renders given application into DOM, providing it with Redux store, if given.
 * @param {Function} Application Root ReactJS component of the app.
 * @param {Object} store Optional. Redux store.
 */
function render(Application, store) {
  let app = <BrowserRouter><Application /></BrowserRouter>;
  if (store) app = <Provider store={store}>{app}</Provider>;
  ReactDom.hydrate(app, document.getElementById('react-view'));
}

/**
 * Initializes the code at client side. It takes care about receiving the data
 * injected at the server-side, and also about setting up client side of hot
 * module reloading (HMR).
 * @param {String} applicationModulePath Optional.
 * @param {Function} getApplication
 * @param {Object} moduleHot
 * @param {Function} storeFactory Optional.
 */
export default async function Launch({
  applicationModulePath,
  getApplication,
  moduleHot,
  storeFactory,
}) {
  let store;
  if (storeFactory) {
    store = await storeFactory(window.ISTATE);
  }
  render(getApplication(), store);

  if (moduleHot && applicationModulePath) {
    moduleHot.accept(applicationModulePath, () =>
      render(getApplication(), store));

    /* HMR of CSS code each time webpack hot middleware updates the code. */
    /* eslint-disable no-underscore-dangle */
    const hotReporter = window.__webpack_hot_middleware_reporter__;
    /* eslint-enable no-underscore-dangle */
    const hotSuccess = hotReporter.success;
    hotReporter.success = () => {
      const stamp = shortId();
      const links = document.querySelectorAll('link[rel=stylesheet][id="tru-style"]');
      for (let i = 0; i < links.length; i += 1) {
        links[i].href = `${links[i].href.match(/[^?]*/)}?v=${stamp}`;
      }
      hotSuccess();
    };
  }
}
